==> tencentcloud-sdk-java-3.1.72-sources.jar: com/tencentcloudapi/yunsou/v20191115/models/SearchResultSeg.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.yunsou.v20191115.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SearchResultSeg extends AbstractModel{

    /**
    * 分词
    */
    @SerializedName("SegStr")
    @Expose
    private String SegStr;

    /**
     * Get 分词 
     * @return SegStr 分词
     */
    public String getSegStr() {
        return this.SegStr;
    }

    /**
     * Set 分词
     * @param SegStr 分词
     */
    public void setSegStr(String SegStr) {
        this.SegStr = SegStr;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SegStr", this.SegStr);

    }
}

==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/yunsou/v20191115/models/SearchResultSeg.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.yunsou.v20191115.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class SearchResultSeg extends AbstractModel{

    /**
    * 分词
    */
    @SerializedName("SegStr")
    @Expose
    private String SegStr;

    /**
     * Get 分词 
     * @return SegStr 分词
     */
    public String getSegStr() {
        return this.SegStr;
    }

    /**
     * Set 分词
     * @param SegStr 分词
     */
    public void setSegStr(String SegStr) {
        this.SegStr = SegStr;
    }

    public SearchResultSeg() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public SearchResultSeg(SearchResultSeg source) {
        if (source.SegStr != null) {
            this.SegStr = new String(source.SegStr);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "SegStr", this.SegStr);

    }
}
